package org.silverpeas.mobile.client.apps.profile.resources;

public class ProfileMessages_ implements org.silverpeas.mobile.client.apps.profile.resources.ProfileMessages {
  
  public com.google.gwt.safehtml.shared.SafeHtml title() {
    return new com.google.gwt.safehtml.shared.SafeHtmlBuilder().appendHtmlConstant("Mettre &agrave; jour mes informations").toSafeHtml();
  }
  
  public com.google.gwt.safehtml.shared.SafeHtml titlePwd() {
    return new com.google.gwt.safehtml.shared.SafeHtmlBuilder().appendHtmlConstant("Mot de passe").toSafeHtml();
  }
  
  public com.google.gwt.safehtml.shared.SafeHtml titleStatus() {
    return new com.google.gwt.safehtml.shared.SafeHtmlBuilder().appendHtmlConstant("Statut").toSafeHtml();
  }
  
  public java.lang.String changeStatus() {
    return "Publier mon statut";
  }
  
  public java.lang.String changePwd() {
    return "Changer mon mot de passe";
  }
  
  public java.lang.String newPwd() {
    return "Nouveau mot de passe";
  }
  
  public java.lang.String repeatNewPwd() {
    return "Confirmation du nouveau mot de passe";
  }
  
  public java.lang.String pwdNotTheSame() {
    return "Les mots de passe ne sont pas identiques";
  }
}
