// .ui.xml template last modified: 1784194033371
package org.silverpeas.mobile.client.apps.profile.pages;

import com.google.gwt.core.client.GWT;
import com.google.gwt.dom.client.Element;
import com.google.gwt.safehtml.client.SafeHtmlTemplates;
import com.google.gwt.safehtml.shared.SafeHtml;
import com.google.gwt.safehtml.shared.SafeHtmlUtils;
import com.google.gwt.safehtml.shared.SafeHtmlBuilder;
import com.google.gwt.safehtml.shared.SafeUri;
import com.google.gwt.safehtml.shared.UriUtils;
import com.google.gwt.uibinder.client.UiBinderUtil;
import com.google.gwt.uibinder.client.UiBinder;
import com.google.gwt.uibinder.client.UiBinderUtil;
import com.google.gwt.user.client.ui.Widget;

public class ProfilePage_StatusPageUiBinderImpl implements UiBinder<com.google.gwt.user.client.ui.Widget, org.silverpeas.mobile.client.apps.profile.pages.ProfilePage>, org.silverpeas.mobile.client.apps.profile.pages.ProfilePage.StatusPageUiBinder {

  interface Template extends SafeHtmlTemplates {
    @Template("<span class='ui-btn-text'>" + "{0}" + "</span>")
    SafeHtml html1(String arg0);
     
    @Template("<span class='ui-btn-text'>" + "{0}" + "</span>")
    SafeHtml html2(String arg0);
     
    @Template("<h2>" + "{0}" + "</h2> <div id='champs-statut'> <div class='ouverture-bulle'></div> <span id='{1}'></span> </div> <div class='ui-controlgroup ui-controlgroup-horizontal'> <div class='ui-controlgroup-controls'> <span id='{2}'></span> </div> </div> <div id='{3}'> <h2>" + "{4}" + "</h2> <div id='champs-password'> <span class='ui-btn-text'>" + "{5}" + "</span> <span id='{6}'></span> <br> <span class='ui-btn-text'>" + "{7}" + "</span> <span id='{8}'></span> </div> <div class='ui-controlgroup ui-controlgroup-horizontal'> <div class='ui-controlgroup-controls'> <span id='{9}'></span> </div> </div> </div>")
    SafeHtml html3(SafeHtml arg0, String arg1, String arg2, String arg3, SafeHtml arg4, String arg5, String arg6, String arg7, String arg8, String arg9);
     
  }

  Template template = GWT.create(Template.class);


  public com.google.gwt.user.client.ui.Widget createAndBindUi(final org.silverpeas.mobile.client.apps.profile.pages.ProfilePage owner) {


    return new Widgets(owner).get_container();
  }

  /**
   * Encapsulates the access to all inner widgets
   */
  class Widgets {
    private final org.silverpeas.mobile.client.apps.profile.pages.ProfilePage owner;


    final com.google.gwt.event.dom.client.ClickHandler handlerMethodWithNameVeryUnlikelyToCollideWithUserFieldNames1 = new com.google.gwt.event.dom.client.ClickHandler() {
      public void onClick(com.google.gwt.event.dom.client.ClickEvent event) {
        owner.publish((com.google.gwt.event.dom.client.ClickEvent) event);
      }
    };

    final com.google.gwt.event.dom.client.ClickHandler handlerMethodWithNameVeryUnlikelyToCollideWithUserFieldNames2 = new com.google.gwt.event.dom.client.ClickHandler() {
      public void onClick(com.google.gwt.event.dom.client.ClickEvent event) {
        owner.changePassword((com.google.gwt.event.dom.client.ClickEvent) event);
      }
    };

    public Widgets(final org.silverpeas.mobile.client.apps.profile.pages.ProfilePage owner) {
      this.owner = owner;
      build_msg();  // more than one getter call detected. Type: IMPORTED, precedence: 1
      build_domId0();  // more than one getter call detected. Type: DOM_ID_HOLDER, precedence: 2
      build_domId1();  // more than one getter call detected. Type: DOM_ID_HOLDER, precedence: 2
      build_domId2();  // more than one getter call detected. Type: DOM_ID_HOLDER, precedence: 2
      build_domId3();  // more than one getter call detected. Type: DOM_ID_HOLDER, precedence: 2
      build_domId4();  // more than one getter call detected. Type: DOM_ID_HOLDER, precedence: 2
      build_domId5();  // more than one getter call detected. Type: DOM_ID_HOLDER, precedence: 2
      build_domId0Element();  // more than one getter call detected. Type: DEFAULT, precedence: 2
      build_domId1Element();  // more than one getter call detected. Type: DEFAULT, precedence: 2
      build_domId3Element();  // more than one getter call detected. Type: DEFAULT, precedence: 2
      build_domId4Element();  // more than one getter call detected. Type: DEFAULT, precedence: 2
      build_domId5Element();  // more than one getter call detected. Type: DEFAULT, precedence: 2
    }

    SafeHtml template_html1() {
      return template.html1("" + get_msg().changeStatus() + "");
    }
    SafeHtml template_html2() {
      return template.html2("" + get_msg().changePwd() + "");
    }
    SafeHtml template_html3() {
      return template.html3(get_msg().titleStatus(), get_domId0(), get_domId1(), get_domId2(), get_msg().titlePwd(), "" + get_msg().newPwd() + "", get_domId3(), "" + get_msg().repeatNewPwd() + "", get_domId4(), get_domId5());
    }

    /**
     * Getter for clientBundleFieldNameUnlikelyToCollideWithUserSpecifiedFieldOkay called 0 times. Type: GENERATED_BUNDLE. Build precedence: 1.
     */
    private org.silverpeas.mobile.client.apps.profile.pages.ProfilePage_StatusPageUiBinderImpl_GenBundle get_clientBundleFieldNameUnlikelyToCollideWithUserSpecifiedFieldOkay() {
      return build_clientBundleFieldNameUnlikelyToCollideWithUserSpecifiedFieldOkay();
    }
    private org.silverpeas.mobile.client.apps.profile.pages.ProfilePage_StatusPageUiBinderImpl_GenBundle build_clientBundleFieldNameUnlikelyToCollideWithUserSpecifiedFieldOkay() {
      // Creation section.
      final org.silverpeas.mobile.client.apps.profile.pages.ProfilePage_StatusPageUiBinderImpl_GenBundle clientBundleFieldNameUnlikelyToCollideWithUserSpecifiedFieldOkay = (org.silverpeas.mobile.client.apps.profile.pages.ProfilePage_StatusPageUiBinderImpl_GenBundle) GWT.create(org.silverpeas.mobile.client.apps.profile.pages.ProfilePage_StatusPageUiBinderImpl_GenBundle.class);
      // Setup section.

      return clientBundleFieldNameUnlikelyToCollideWithUserSpecifiedFieldOkay;
    }

    /**
     * Getter for msg called 6 times. Type: IMPORTED. Build precedence: 1.
     */
    private org.silverpeas.mobile.client.apps.profile.resources.ProfileMessages msg;
    private org.silverpeas.mobile.client.apps.profile.resources.ProfileMessages get_msg() {
      return msg;
    }
    private org.silverpeas.mobile.client.apps.profile.resources.ProfileMessages build_msg() {
      // Creation section.
      msg = owner.msg;
      assert msg != null : "UiField msg with 'provided = true' was null";
      // Setup section.

      return msg;
    }

    /**
     * Getter for container called 1 times. Type: DEFAULT. Build precedence: 1.
     */
    private com.google.gwt.user.client.ui.HTMLPanel get_container() {
      return build_container();
    }
    private com.google.gwt.user.client.ui.HTMLPanel build_container() {
      // Creation section.
      final com.google.gwt.user.client.ui.HTMLPanel container = new com.google.gwt.user.client.ui.HTMLPanel(template_html3().asString());
      // Setup section.
      container.setStyleName("ui-content ui-body-a");

      {
        // Attach section.
        UiBinderUtil.TempAttachment __attachRecord__ = UiBinderUtil.attachToDom(container.getElement());

        get_domId0Element().get();
        get_domId1Element().get();
        get_changePwdArea();
        get_domId3Element().get();
        get_domId4Element().get();
        get_domId5Element().get();

        // Detach section.
        __attachRecord__.detach();
      }
      container.addAndReplaceElement(get_status(), get_domId0Element().get());
      container.addAndReplaceElement(get_publish(), get_domId1Element().get());
      container.addAndReplaceElement(get_pwd1(), get_domId3Element().get());
      container.addAndReplaceElement(get_pwd2(), get_domId4Element().get());
      container.addAndReplaceElement(get_changePwd(), get_domId5Element().get());

      this.owner.container = container;

      return container;
    }

    /**
     * Getter for domId0 called 2 times. Type: DOM_ID_HOLDER. Build precedence: 2.
     */
    private java.lang.String domId0;
    private java.lang.String get_domId0() {
      return domId0;
    }
    private java.lang.String build_domId0() {
      // Creation section.
      domId0 = com.google.gwt.dom.client.Document.get().createUniqueId();
      // Setup section.

      return domId0;
    }

    /**
     * Getter for status called 1 times. Type: DEFAULT. Build precedence: 2.
     */
    private com.google.gwt.user.client.ui.TextArea get_status() {
      return build_status();
    }
    private com.google.gwt.user.client.ui.TextArea build_status() {
      // Creation section.
      final com.google.gwt.user.client.ui.TextArea status = (com.google.gwt.user.client.ui.TextArea) GWT.create(com.google.gwt.user.client.ui.TextArea.class);
      // Setup section.
      status.setStyleName("ui-input-text  ui-body-inherit");

      this.owner.status = status;

      return status;
    }

    /**
     * Getter for domId0Element called 2 times. Type: DEFAULT. Build precedence: 2.
     */
    private com.google.gwt.uibinder.client.LazyDomElement domId0Element;
    private com.google.gwt.uibinder.client.LazyDomElement get_domId0Element() {
      return domId0Element;
    }
    private com.google.gwt.uibinder.client.LazyDomElement build_domId0Element() {
      // Creation section.
      domId0Element = new com.google.gwt.uibinder.client.LazyDomElement<Element>(get_domId0());
      // Setup section.

      return domId0Element;
    }

    /**
     * Getter for domId1 called 2 times. Type: DOM_ID_HOLDER. Build precedence: 2.
     */
    private java.lang.String domId1;
    private java.lang.String get_domId1() {
      return domId1;
    }
    private java.lang.String build_domId1() {
      // Creation section.
      domId1 = com.google.gwt.dom.client.Document.get().createUniqueId();
      // Setup section.

      return domId1;
    }

    /**
     * Getter for publish called 1 times. Type: DEFAULT. Build precedence: 2.
     */
    private com.google.gwt.user.client.ui.Anchor get_publish() {
      return build_publish();
    }
    private com.google.gwt.user.client.ui.Anchor build_publish() {
      // Creation section.
      final com.google.gwt.user.client.ui.Anchor publish = (com.google.gwt.user.client.ui.Anchor) GWT.create(com.google.gwt.user.client.ui.Anchor.class);
      // Setup section.
      publish.setHTML(template_html1().asString());
      publish.setStyleName("btn-validate ui-link");
      publish.addClickHandler(handlerMethodWithNameVeryUnlikelyToCollideWithUserFieldNames1);

      this.owner.publish = publish;

      return publish;
    }

    /**
     * Getter for domId1Element called 2 times. Type: DEFAULT. Build precedence: 2.
     */
    private com.google.gwt.uibinder.client.LazyDomElement domId1Element;
    private com.google.gwt.uibinder.client.LazyDomElement get_domId1Element() {
      return domId1Element;
    }
    private com.google.gwt.uibinder.client.LazyDomElement build_domId1Element() {
      // Creation section.
      domId1Element = new com.google.gwt.uibinder.client.LazyDomElement<Element>(get_domId1());
      // Setup section.

      return domId1Element;
    }

    /**
     * Getter for changePwdArea called 1 times. Type: DEFAULT. Build precedence: 2.
     */
    private com.google.gwt.dom.client.DivElement get_changePwdArea() {
      return build_changePwdArea();
    }
    private com.google.gwt.dom.client.DivElement build_changePwdArea() {
      // Creation section.
      final com.google.gwt.dom.client.DivElement changePwdArea = new com.google.gwt.uibinder.client.LazyDomElement(get_domId2()).get().cast();
      // Setup section.

      this.owner.changePwdArea = changePwdArea;

      return changePwdArea;
    }

    /**
     * Getter for domId2 called 2 times. Type: DOM_ID_HOLDER. Build precedence: 2.
     */
    private java.lang.String domId2;
    private java.lang.String get_domId2() {
      return domId2;
    }
    private java.lang.String build_domId2() {
      // Creation section.
      domId2 = com.google.gwt.dom.client.Document.get().createUniqueId();
      // Setup section.

      return domId2;
    }

    /**
     * Getter for domId3 called 2 times. Type: DOM_ID_HOLDER. Build precedence: 2.
     */
    private java.lang.String domId3;
    private java.lang.String get_domId3() {
      return domId3;
    }
    private java.lang.String build_domId3() {
      // Creation section.
      domId3 = com.google.gwt.dom.client.Document.get().createUniqueId();
      // Setup section.

      return domId3;
    }

    /**
     * Getter for pwd1 called 1 times. Type: DEFAULT. Build precedence: 2.
     */
    private com.google.gwt.user.client.ui.PasswordTextBox get_pwd1() {
      return build_pwd1();
    }
    private com.google.gwt.user.client.ui.PasswordTextBox build_pwd1() {
      // Creation section.
      final com.google.gwt.user.client.ui.PasswordTextBox pwd1 = (com.google.gwt.user.client.ui.PasswordTextBox) GWT.create(com.google.gwt.user.client.ui.PasswordTextBox.class);
      // Setup section.
      pwd1.setStyleName("ui-input-text ui-body-inherit");

      this.owner.pwd1 = pwd1;

      return pwd1;
    }

    /**
     * Getter for domId3Element called 2 times. Type: DEFAULT. Build precedence: 2.
     */
    private com.google.gwt.uibinder.client.LazyDomElement domId3Element;
    private com.google.gwt.uibinder.client.LazyDomElement get_domId3Element() {
      return domId3Element;
    }
    private com.google.gwt.uibinder.client.LazyDomElement build_domId3Element() {
      // Creation section.
      domId3Element = new com.google.gwt.uibinder.client.LazyDomElement<Element>(get_domId3());
      // Setup section.

      return domId3Element;
    }

    /**
     * Getter for domId4 called 2 times. Type: DOM_ID_HOLDER. Build precedence: 2.
     */
    private java.lang.String domId4;
    private java.lang.String get_domId4() {
      return domId4;
    }
    private java.lang.String build_domId4() {
      // Creation section.
      domId4 = com.google.gwt.dom.client.Document.get().createUniqueId();
      // Setup section.

      return domId4;
    }

    /**
     * Getter for pwd2 called 1 times. Type: DEFAULT. Build precedence: 2.
     */
    private com.google.gwt.user.client.ui.PasswordTextBox get_pwd2() {
      return build_pwd2();
    }
    private com.google.gwt.user.client.ui.PasswordTextBox build_pwd2() {
      // Creation section.
      final com.google.gwt.user.client.ui.PasswordTextBox pwd2 = (com.google.gwt.user.client.ui.PasswordTextBox) GWT.create(com.google.gwt.user.client.ui.PasswordTextBox.class);
      // Setup section.
      pwd2.setStyleName("ui-input-text ui-body-inherit");

      this.owner.pwd2 = pwd2;

      return pwd2;
    }

    /**
     * Getter for domId4Element called 2 times. Type: DEFAULT. Build precedence: 2.
     */
    private com.google.gwt.uibinder.client.LazyDomElement domId4Element;
    private com.google.gwt.uibinder.client.LazyDomElement get_domId4Element() {
      return domId4Element;
    }
    private com.google.gwt.uibinder.client.LazyDomElement build_domId4Element() {
      // Creation section.
      domId4Element = new com.google.gwt.uibinder.client.LazyDomElement<Element>(get_domId4());
      // Setup section.

      return domId4Element;
    }

    /**
     * Getter for domId5 called 2 times. Type: DOM_ID_HOLDER. Build precedence: 2.
     */
    private java.lang.String domId5;
    private java.lang.String get_domId5() {
      return domId5;
    }
    private java.lang.String build_domId5() {
      // Creation section.
      domId5 = com.google.gwt.dom.client.Document.get().createUniqueId();
      // Setup section.

      return domId5;
    }

    /**
     * Getter for changePwd called 1 times. Type: DEFAULT. Build precedence: 2.
     */
    private com.google.gwt.user.client.ui.Anchor get_changePwd() {
      return build_changePwd();
    }
    private com.google.gwt.user.client.ui.Anchor build_changePwd() {
      // Creation section.
      final com.google.gwt.user.client.ui.Anchor changePwd = (com.google.gwt.user.client.ui.Anchor) GWT.create(com.google.gwt.user.client.ui.Anchor.class);
      // Setup section.
      changePwd.setHTML(template_html2().asString());
      changePwd.setStyleName("btn-validate ui-link");
      changePwd.addClickHandler(handlerMethodWithNameVeryUnlikelyToCollideWithUserFieldNames2);

      this.owner.changePwd = changePwd;

      return changePwd;
    }

    /**
     * Getter for domId5Element called 2 times. Type: DEFAULT. Build precedence: 2.
     */
    private com.google.gwt.uibinder.client.LazyDomElement domId5Element;
    private com.google.gwt.uibinder.client.LazyDomElement get_domId5Element() {
      return domId5Element;
    }
    private com.google.gwt.uibinder.client.LazyDomElement build_domId5Element() {
      // Creation section.
      domId5Element = new com.google.gwt.uibinder.client.LazyDomElement<Element>(get_domId5());
      // Setup section.

      return domId5Element;
    }
  }
}
